-- De definitie van de database, enigszins aangepast van de definitie gegeven op de website van het boek

CREATE TABLE Leverancier (
  leveranciercode   CHAR(5) NOT NULL,
  naam		    VARCHAR(30) NOT NULL,
  adres		    VARCHAR(30) NOT NULL,
  postcode	    CHAR(6) NOT NULL,
  woonplaats	    VARCHAR(30) NOT NULL,
  telefoonnummer    CHAR(10),
  PRIMARY KEY(leveranciercode)
);
CREATE TABLE Product (
  productcode		VARCHAR(5) NOT NULL,
  productomschrijving	TEXT NOT NULL,
  inkoopprijs		DECIMAL(8,2) NOT NULL,
  verkoopprijs		DECIMAL(8,2) NOT NULL,
  voorraad		SMALLINT NOT NULL,
  PRIMARY KEY(productcode)
);
CREATE TABLE Kan_leveren (
  leveranciercode CHAR(5) NOT NULL,
  productcode	  VARCHAR(5) NOT NULL,
  PRIMARY KEY(leveranciercode, productcode),
  FOREIGN KEY(leveranciercode) REFERENCES leverancier,
  FOREIGN KEY(productcode) REFERENCES product
);
CREATE TABLE Bestelling (
  bestelnummer	    DECIMAL(5) NOT NULL,
  besteldatum	    DATE NOT NULL,
  contactpersoon    VARCHAR(30) NOT NULL,
  leveranciercode   CHAR(5) NOT NULL,
  PRIMARY KEY(bestelnummer),
  FOREIGN KEY(leveranciercode) REFERENCES leverancier
);
CREATE TABLE Bestelregel (
  bestelnummer DECIMAL(5) NOT NULL,
  productcode VARCHAR(5) NOT NULL,
  besteld_aantal SMALLINT NOT NULL,
  PRIMARY KEY(bestelnummer,productcode),
  FOREIGN KEY(bestelnummer) REFERENCES bestelling,
  FOREIGN KEY(productcode) REFERENCES product
);

-- Vullen van de database als in H4
-- tabel Leverancier (p. 183)
INSERT INTO Leverancier VALUES ("LEV45", "De Vulpen", "Anjelierstraat 23", "7388XX", "Apeldoorn", "0553366551");
INSERT INTO Leverancier VALUES ("LEV72", "Papier BV", "Hoogstraat 1", "9711LN", "Groningen", "0503746103");
INSERT INTO Leverancier VALUES ("LEV73", "Kantoor BV", "Parkweg 127", "7602JK", "Almelo", "0546253642");
INSERT INTO Leverancier VALUES ("LEV99", "Bacon BV", "Slotweg 18", "9705KK", "Groningen", "0501234567");

-- tabel Product (p. 184)
INSERT INTO Product VALUES ("JJ83", "Balpen rood", 1.75, 2.10, 15);
INSERT INTO Product VALUES ("NA256", "Potlood HB", 0.85, 1.00, 22);
INSERT INTO Product VALUES ("NB221", "Schrijfblok", 2.00, 2.95, 20);
INSERT INTO Product VALUES ("NB222", "Schrijfblok", 1.75, 2.60, 18);
INSERT INTO Product VALUES ("XX24", "Vulpeninkt", 6.95, 8.35, 6);
INSERT INTO Product VALUES ("ZA287", "Penvulling zwart", 0.95, 1.15, 22);

-- tabel Bestelling (p. 184)
INSERT INTO Bestelling VALUES (99023, 2007-05-31, "H. Kral", "LEV45");
INSERT INTO Bestelling VALUES (99024, 2007-05-31, "P. de Jong", "LEV72");
INSERT INTO Bestelling VALUES (99025, 2007-06-07, "H. Kral", "LEV73");

-- tabel Kan_leveren (p. 184)
INSERT INTO Kan_leveren VALUES ("LEV45", "JJ83");
INSERT INTO Kan_leveren VALUES ("LEV45", "NA256");
INSERT INTO Kan_leveren VALUES ("LEV45", "XX24");
INSERT INTO Kan_leveren VALUES ("LEV45", "ZA287");
INSERT INTO Kan_leveren VALUES ("LEV72", "NB221");
INSERT INTO Kan_leveren VALUES ("LEV72", "NB222");
INSERT INTO Kan_leveren VALUES ("LEV72", "XX24");
INSERT INTO Kan_leveren VALUES ("LEV73", "JJ83");
INSERT INTO Kan_leveren VALUES ("LEV73", "NA256");
INSERT INTO Kan_leveren VALUES ("LEV73", "NB221");
INSERT INTO Kan_leveren VALUES ("LEV73", "ZA287");

-- tabel Bestelregel (p. 284)
INSERT INTO Bestelregel VALUES (99023, "XX24", 12);
INSERT INTO Bestelregel VALUES (99023, "ZA287", 24);
INSERT INTO Bestelregel VALUES (99023, "JJ83", 24);
INSERT INTO Bestelregel VALUES (99023, "NA256", 12);
INSERT INTO Bestelregel VALUES (99024, "NB221", 24);
INSERT INTO Bestelregel VALUES (99025, "NA256", 12);
INSERT INTO Bestelregel VALUES (99025, "NB221", 24);
